==> mx-packageinstaller-pkglist_19.07.01.tar.xz: mx-packageinstaller-pkglist/HP_printing.pm <==
<?xml version="1.0"?>
<app>

<category>
Printing
</category>

<name>
HP Printing
</name>

<description>
   <am>HPLIP and printing extras</am>
   <ar>HPLIP and printing extras</ar>
   <bg>HPLIP and printing extras</bg>
   <ca>HPLIP i extres d'impressió</ca>
   <cs>HPLIP and printing extras</cs>
   <da>Ekstra til HPLIP og udskrivning</da>
   <de>HPLIP (HP's Linux Imaging and Printing) und Druck-Extras</de>
   <el>HPLIP και εκτύπωση</el>
   <en>HPLIP and printing extras</en>
   <es>HPLIP y complementos de impresión</es>
   <et>HPLIP and printing extras</et>
   <eu>HPLIP and printing extras</eu>
   <fa>HPLIP and printing extras</fa>
   <fi>HPLIP and printing extras</fi>
   <fr>HPLIP et utilitaires d'impression</fr>
   <he_IL>HPLIP and printing extras</he_IL>
   <hi>HPLIP and printing extras</hi>
   <hr>HPLIP and printing extras</hr>
   <hu>HPLIP and printing extras</hu>
   <id>HPLIP and printing extras</id>
   <is>HPLIP and printing extras</is>
   <it>HPLIP ed ulteriori pacchetti per la stampa</it>
   <ja_JP>HPLIP and printing extras</ja_JP>
   <ja>HPLIP and printing extras</ja>
   <kk>HPLIP and printing extras</kk>
   <ko>HPLIP and printing extras</ko>
   <lt>HPLIP and printing extras</lt>
   <mk>HPLIP and printing extras</mk>
   <nb>HPLIP and printing extras</nb>
   <nl>HPLIP en printing extras</nl>
   <pl>HPLIP i dodatki do drukowania</pl>
   <pt_BR>HPLIP and printing extras</pt_BR>
   <pt>Criação de imagens e impressão para computadores HP com Linux [HP Linux Imaging and Printing] e extras de impressão</pt>
   <ro>HPLIP and printing extras</ro>
   <ru>HPLIP и вспомогательные компоненты печати</ru>
   <sk>HPLIP and printing extras</sk>
   <sl>HPLIP and printing extras</sl>
   <sq>HPLIP and printing extras</sq>
   <sr>HPLIP and printing extras</sr>
   <sv>HPLIP och utskrifts-extras</sv>
   <tr>HPLIP and printing extras</tr>
   <uk>HPLIP and printing extras</uk>
   <zh_CN>HPLIP and printing extras</zh_CN>
   <zh_TW>HPLIP and printing extras</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
printer-driver-hpijs
hpijs-ppds
hplip-data
hplip-gui
cups
cups-pdf
cups-client
magicfilter
gv
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
printer-driver-hpijs
hpijs-ppds
hplip-data
hplip-gui
magicfilter
gv
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.01.tar.xz: mx-packageinstaller-pkglist/HP_printing.pm <==
<?xml version="1.0"?>
<app>

<category>
Printing
</category>

<name>
HP Printing
</name>

<description>
   <am>HPLIP and printing extras</am>
   <ar>HPLIP and printing extras</ar>
   <bg>HPLIP and printing extras</bg>
   <ca>HPLIP i extres d'impressió</ca>
   <cs>HPLIP and printing extras</cs>
   <da>Ekstra til HPLIP og udskrivning</da>
   <de>HPLIP (HP's Linux Imaging and Printing) und Druck-Extras</de>
   <el>HPLIP και εκτύπωση</el>
   <en>HPLIP and printing extras</en>
   <es>HPLIP y complementos de impresión</es>
   <et>HPLIP and printing extras</et>
   <eu>HPLIP and printing extras</eu>
   <fa>HPLIP and printing extras</fa>
   <fi>HPLIP and printing extras</fi>
   <fr>HPLIP et utilitaires d'impression</fr>
   <he_IL>HPLIP and printing extras</he_IL>
   <hi>HPLIP and printing extras</hi>
   <hr>HPLIP and printing extras</hr>
   <hu>HPLIP and printing extras</hu>
   <id>HPLIP and printing extras</id>
   <is>HPLIP and printing extras</is>
   <it>HPLIP ed ulteriori pacchetti per la stampa</it>
   <ja_JP>HPLIP and printing extras</ja_JP>
   <ja>HPLIP and printing extras</ja>
   <kk>HPLIP and printing extras</kk>
   <ko>HPLIP and printing extras</ko>
   <lt>HPLIP ir spausdinimo papildiniai</lt>
   <mk>HPLIP and printing extras</mk>
   <nb>HPLIP and printing extras</nb>
   <nl>HPLIP en printing extras</nl>
   <pl>HPLIP i dodatki do drukowania</pl>
   <pt_BR>Criação de imagens e impressão para computadores HP com Linux [HP Linux Imaging and Printing] e extras de impressão</pt_BR>
   <pt>Criação de imagens e impressão para computadores HP com Linux [HP Linux Imaging and Printing] e extras de impressão</pt>
   <ro>HPLIP and printing extras</ro>
   <ru>HPLIP и вспомогательные компоненты печати</ru>
   <sk>HPLIP and printing extras</sk>
   <sl>HPLIP and printing extras</sl>
   <sq>HPLIP and printing extras</sq>
   <sr>HPLIP and printing extras</sr>
   <sv>HPLIP och utskrifts-extras</sv>
   <tr>HPLIP and printing extras</tr>
   <uk>HPLIP and printing extras</uk>
   <zh_CN>HPLIP and printing extras</zh_CN>
   <zh_TW>HPLIP and printing extras</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
printer-driver-hpijs
hpijs-ppds
hplip-data
hplip-gui
cups
cups-pdf
cups-client
magicfilter
gv
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
printer-driver-hpijs
hpijs-ppds
hplip-data
hplip-gui
magicfilter
gv
</uninstall_package_names>
</app>
